%rocket_analysis
% 
% Loads in CAPSTONE dataloger output saved in space delimited .txt file
% rocket.txt. Columns are time /s, Force /N and Pressure /kPa.
% Pressure data is interpolated at the same times the higher data rate
% Force measurements are recorded. Both force and pressure are then plotted
% against time.
%
% LAST UPDATED by Andy French May 2017

function rocket_analysis

%Set fontsize for graphs
fsize = 16;

%Time range /s for launch close up
tstart = 75.75;
tstop = 76.5;

%Time range /s for thrust extremeclose up
ttstart = 76;
ttstop = 76.25;


%

%Load data
[t,F,P] = textread('rocket.txt',...
    '%f%f%f',...
    'delimiter',' ',...
    'emptyvalue',NaN,...
    'headerlines',2);

%Double force F to take into account mechanical disadvantage of pivot
F = 2*F;

%Remove NaN values from Pressure Data
tP = t;
nans = isnan(P);
tP(nans) = [];
P(nans) = [];

%Interpolate using t times
P = interp1( tP, P, t );

% Plot whole range of data

%Plot Pressure vs time and save a PNG file
plot(t,P);
xlabel('time /s','fontsize',fsize);
ylabel('Pressure /kPa','fontsize',fsize);
title('Air pressure inside rocket','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on
print(gcf,'pressure vs time.png','-dpng','-r300');
clf

%Plot Force vs time
plot(t,F);
xlabel('time /s','fontsize',fsize);
ylabel('Force /N','fontsize',fsize);
title('Rocket thrust','fontsize',fsize);
set(gca,'fontsize',fsize);
grid on
print(gcf,'thrust vs time.png','-dpng','-r300');
clf

% Close up on launch

%Plot Pressure vs time and save a PNG file
plot(t,P);
xlabel('time /s','fontsize',fsize);
ylabel('Pressure /kPa','fontsize',fsize);
title('Air pressure inside rocket','fontsize',fsize);
set(gca,'fontsize',fsize);
xlim( [tstart,tstop] )
grid on
print(gcf,'launch pressure vs time.png','-dpng','-r300');
clf

%Plot Force vs time
plot(t,F);
xlabel('time /s','fontsize',fsize);
ylabel('Force /N','fontsize',fsize);
title('Rocket thrust','fontsize',fsize);
set(gca,'fontsize',fsize);
xlim( [tstart,tstop] )
grid on
print(gcf,'launch thrust vs time.png','-dpng','-r300');
clf

%Plot Force vs time extreme close up
plot(t,F);
xlabel('time /s','fontsize',fsize);
ylabel('Force /N','fontsize',fsize);
title('Rocket thrust','fontsize',fsize);
set(gca,'fontsize',fsize);
xlim( [ttstart,ttstop] )
grid on
print(gcf,'launch thrust vs time close up.png','-dpng','-r300');
clf
close(gcf);

%End of code